@@ -73,7 +73,17 @@ def bic_counter(data, arities, cols, weight=None):
     return bic
 
 
-def nal(data, cols, alpha=0.4):
+def nal(data, cols, alpha=0.3):
+    arities = np.amax(data, axis=0) + 1
+    data_local = np.delete(data, data[:, cols].min(axis=1) < 0, axis=0)
+    if data_local.shape[0] == 0:
+        return -np.inf
+    else:
+        return nal_counter(data_local, arities, cols,
+                           weight=np.ones(data_local.shape[0]) * data.shape[0] / data_local.shape[0], alpha=alpha)
+
+
+def nal_vn(data, cols, alpha=0.4):
     arities = np.amax(data, axis=0) + 1
     data_local = np.delete(data, data[:, cols].min(axis=1) < 0, axis=0)
     if data_local.shape[0] == 0:
@@ -181,7 +191,7 @@ def compute_weights(data, varnames, W_ids, cause_list):
                     (data_beta.min(axis=1) >= 0) & (data_beta.max(axis=1) != np.iinfo(data.dtype).max)]
                 denominator = data_beta[
                     (data_beta.min(axis=1) >= 0) & (data_beta.max(axis=1) != np.iinfo(data.dtype).max) & (
-                                data[:, varnames.index(ri)] >= 0)]
+                            data[:, varnames.index(ri)] >= 0)]
                 arities = np.amax(numerator, axis=0) + 1
                 f_w = density_counter(numerator, arities).reshape(arities)
                 f_wr = density_counter(denominator, arities).reshape(arities)
@@ -230,7 +240,7 @@ def local_score(data, cols, score_function='default', weights=None, alpha=0.4):
         if score_function == 'default':
             score_function = 'bic' if 'int' in data.dtype.name else 'bic_g'
         try:
-            if score_function in ['nal', 'nal_va']:
+            if score_function in ['nal', 'nal_va', 'nal_vn']:
                 ls = globals()[score_function](data, np.asarray(cols), alpha=alpha)
             else:
                 ls = globals()[score_function](data, np.asarray(cols), weights)
