@@ -612,14 +612,15 @@ def ges(data, method='complete', score='default', prune=True, thres=0.1, alpha=0
             operator_candidate = []
             for x in varnames:
                 for y in candidate[x]:
-                    # do insert (var, can, T)
-                    # ncnav means neighbour of can but not adjacent of var
-                    ncnav = [v for v in cpdag[y]['nei'] if
+                    # do insert (x, y, T)
+                    # nynax are undirected neighbours of y which are not adjacent to x
+                    nynax = [v for v in cpdag[y]['nei'] if
                              v not in set().union(*cpdag[x].values()) and x not in cpdag[v]['par']]
-                    for T in all_subsets(ncnav):
+                    for T in all_subsets(nynax):
                         T = list(T)
                         if validity_test(cpdag, x, y, T, 'insert'):
                             # compute change in score
+                            # NA are undirected neighbours of y which are adjacent to x
                             NA = [v for v in cpdag[y]['nei'] if
                                   v in set().union(*cpdag[x].values()) or x in cpdag[v]['par']]
                             parents_new = tuple(sorted(NA + T + cpdag[y]['par'] + [x]))
@@ -655,11 +656,12 @@ def ges(data, method='complete', score='default', prune=True, thres=0.1, alpha=0
             operator_candidate = []
             for y in varnames:
                 for x in set().union(*cpdag[y].values()):
-                    # nvac means neighbours of var that are adjacent to can
-                    nvac = [v for v in cpdag[y]['nei'] if v in set().union(*cpdag[x].values()) or x in cpdag[v]['par']]
-                    for H in all_subsets(nvac):
+                    # nvac are undirected neighbours of y which are adjacent to x
+                    nyax = [v for v in cpdag[y]['nei'] if v in set().union(*cpdag[x].values()) or x in cpdag[v]['par']]
+                    for H in all_subsets(nyax):
                         H = list(H)
                         if validity_test(cpdag, x, y, H, 'delete'):
+                            # NA are undirected neighbours of y which are adjacent to x
                             NA = [v for v in cpdag[y]['nei'] if
                                   v in set().union(*cpdag[x].values()) or x in cpdag[v]['par']]
                             NAwH = [v for v in NA if v not in H]
@@ -739,14 +741,15 @@ def ges(data, method='complete', score='default', prune=True, thres=0.1, alpha=0
             operator_candidate = []
             for x in varnames:
                 for y in candidate[x]:
-                    # do insert (var, can, T)
-                    # ncnav means neighbour of can but not adjacent of var
-                    ncnav = [v for v in cpdag[y]['nei'] if
+                    # do insert (x, y, T)
+                    # nynax are undirected neighbours of y which are not adjacent to x
+                    nynax = [v for v in cpdag[y]['nei'] if
                              v not in set().union(*cpdag[x].values()) and x not in cpdag[v]['par']]
-                    for T in all_subsets(ncnav):
+                    for T in all_subsets(nynax):
                         T = list(T)
                         if validity_test(cpdag, x, y, T, 'insert'):
                             # compute change in score
+                            # NA are undirected neighbours of y which are adjacent to x
                             NA = [v for v in cpdag[y]['nei'] if
                                   v in set().union(*cpdag[x].values()) or x in cpdag[v]['par']]
                             parents_new = tuple(sorted(NA + T + cpdag[y]['par'] + [x]))
@@ -788,12 +791,13 @@ def ges(data, method='complete', score='default', prune=True, thres=0.1, alpha=0
             operator_candidate = []
             for y in varnames:
                 for x in set().union(*cpdag[y].values()):
-                    # nvac means neighbours of var that are adjacent to can
-                    nvac = [v for v in cpdag[y]['nei'] if
+                    # nyax are neighbours of y which are adjacent to x
+                    nyax = [v for v in cpdag[y]['nei'] if
                             v in set().union(*cpdag[x].values()) or x in cpdag[v]['par']]
-                    for H in all_subsets(nvac):
+                    for H in all_subsets(nyax):
                         H = list(H)
                         if validity_test(cpdag, x, y, H, 'delete'):
+                            # NA are undirected neighbours of y which are adjacent to x
                             NA = [v for v in cpdag[y]['nei'] if
                                   v in set().union(*cpdag[x].values()) or x in cpdag[v]['par']]
                             NAwH = [v for v in NA if v not in H]
